# Table of Contents

- [apptio-integration](<./apptio-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Apptio Integration](<./Apptio-Integration.md>)
  - [Overview](<./Apptio-Integration/Overview.md>)
  - [Integration Use Case: Application Portfolio Management](<./Apptio-Integration/Integration-Use-Case-Application-Portfolio-Management.md>)
  - [Integration Use Case: Application Rationalization](<./Apptio-Integration/Integration-Use-Case-Application-Rationalization.md>)
  - [Integration Use Case: Technology Risk and Compliance](<./Apptio-Integration/Integration-Use-Case-Technology-Risk-and-Compliance.md>)
  - [Integration Use Case: Cloud Migration](<./Apptio-Integration/Integration-Use-Case-Cloud-Migration.md>)
  - [How the Integration Works](<./Apptio-Integration/How-the-Integration-Works.md>)
  - [Base Integration](<./Apptio-Integration/Base-Integration.md>)
  - [Advanced Integration](<./Apptio-Integration/Advanced-Integration.md>)
  - [Key Features](<./Apptio-Integration/Key-Features.md>)
  - [Data Synchronization](<./Apptio-Integration/Data-Synchronization.md>)
